@@ -33,6 +33,8 @@ with requests.Session() as session:
 
     def set_user(user):
         user_info = user
+        print('set_user => ' + user)
+        print('set_user => ' + user_info)
 
 
     def set_tag(property_name, property_value):
@@ -121,6 +123,7 @@ with requests.Session() as session:
 
 
     def create_log(payload):
+        print('create_log => ' + user_api_key)
         response = session.post(f'{HttpClientConfig.alertNowURL}/integration/appinsight/v1/{user_api_key}',
                                 data=jsonpickle.encode(payload))
         return response
